/**
 * $Id: QuarantinePacket.java 57 2007-11-12 15:51:29Z elkner $ 
 * 
 * Copyright (c) 2005-2007 Jens Elkner.
 * All Rights Reserved.
 *
 * This software is the proprietary information of Jens Elkner.
 * Use is subject to license terms.
 */
package de.ovgu.cs.milter4j.reply;

import java.io.ByteArrayOutputStream;
import java.io.IOException;

import de.ovgu.cs.milter4j.Modification;
import de.ovgu.cs.milter4j.util.Misc;

/**
 * Inform the MTA, that the message was quarantined for the given reason.
 * <p>
 * Requires {@link Modification#QUARANTINE} negotiation.
 * @author 	Jens Elkner
 * @version	$Revision: 57 $
 */
public class QuarantinePacket
	extends Packet
{
	String reason;

	/**
	 * Create the packet.
	 * @param reason	The mail-safe quarantine reason.
	 * @throws IllegalArgumentException if reason is <code>null</code> or empty
	 * @see javax.mail.internet.MimeUtility#encodeText(String, String, String)
	 */
	public QuarantinePacket(String reason) {
		super(Type.QUARANTINE);
		this.reason = reason == null ? "" : reason.trim();
		if (this.reason.length() == 0) {
			throw new IllegalArgumentException("null or empty reason not allowed");
		}
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public byte[] getData() throws IOException {
		ByteArrayOutputStream bos = 
			new ByteArrayOutputStream(reason.length() + 1);
		bos.write(Misc.getBytes(reason));
		bos.write(0);
		return bos.toByteArray();
	}
}
